@@ -1,11 +1,12 @@
 extern crate jsonwebtoken as jwt;
-extern crate rustc_serialize;
+#[macro_use]
+extern crate serde_derive;
 
-use jwt::{encode, decode, Header, Algorithm};
-use jwt::errors::{Error};
+use jwt::{encode, decode, Header, Algorithm, Validation};
+use jwt::errors::{ErrorKind};
 
 
-#[derive(Debug, RustcEncodable, RustcDecodable)]
+#[derive(Debug, Serialize, Deserialize)]
 struct Claims {
     sub: String,
     company: String
@@ -22,15 +23,16 @@ fn main() {
     header.kid = Some("signing_key".to_owned());
     header.alg = Algorithm::HS512;
 
-    let token = match encode(header, &my_claims, key.as_ref()) {
+    let token = match encode(&header, &my_claims, key.as_ref()) {
         Ok(t) => t,
         Err(_) => panic!() // in practice you would return the error
     };
+    println!("{:?}", token);
 
-    let token_data = match decode::<Claims>(&token, key.as_ref(), Algorithm::HS512) {
+    let token_data = match decode::<Claims>(&token, key.as_ref(), &Validation::default()) {
         Ok(c) => c,
-        Err(err) => match err {
-            Error::InvalidToken => panic!(), // Example on how to handle a specific error
+        Err(err) => match *err.kind() {
+            ErrorKind::InvalidToken => panic!(), // Example on how to handle a specific error
             _ => panic!()
         }
     };
